diff --git a/include/traceevent/event-parse.h b/include/traceevent/event-parse.h
index bdc6101..0ac9e19 100644
--- a/include/traceevent/event-parse.h
+++ b/include/traceevent/event-parse.h
@@ -394,9 +394,9 @@ void tep_print_plugins(struct trace_seq *s,
 /* tep_handle */
 typedef char *(tep_func_resolver_t)(void *priv,
 				    unsigned long long *addrp, char **modp);
-void tep_set_flag(struct tep_handle *tep, enum tep_flag flag);
-void tep_reset_flag(struct tep_handle *tep, enum tep_flag flag);
-int tep_check_flag(struct tep_handle *tep, enum tep_flag flag);
+void tep_set_flag(struct tep_handle *tep, int flag);
+void tep_clear_flag(struct tep_handle *tep, enum tep_flag flag);
+bool tep_test_flag(struct tep_handle *tep, enum tep_flag flags);
 
 static inline int tep_host_bigendian(void)
 {
@@ -559,8 +559,8 @@ void tep_set_latency_format(struct tep_handle *pevent, int lat);
 int tep_get_header_page_size(struct tep_handle *pevent);
 void tep_set_parsing_failures(struct tep_handle *tep, int parsing_failures);
 int tep_get_parsing_failures(struct tep_handle *tep);
-int tep_get_header_page_ts_size(struct tep_handle *tep);
-int tep_is_old_format(struct tep_handle *pevent);
+int tep_get_header_timestamp_size(struct tep_handle *tep);
+bool tep_is_old_format(struct tep_handle *tep);
 void tep_set_print_raw(struct tep_handle *tep, int print_raw);
 void tep_set_test_filters(struct tep_handle *tep, int test_filters);
 
diff --git a/lib/trace-cmd/trace-input.c b/lib/trace-cmd/trace-input.c
index 6938513..643d8ac 100644
--- a/lib/trace-cmd/trace-input.c
+++ b/lib/trace-cmd/trace-input.c
@@ -1038,7 +1038,7 @@ static int update_page_info(struct tracecmd_input *handle, int cpu)
 	struct kbuffer *kbuf = handle->cpu_data[cpu].kbuf;
 
 	/* FIXME: handle header page */
-	if (tep_get_header_page_ts_size(pevent) != 8) {
+	if (tep_get_header_timestamp_size(pevent) != 8) {
 		warning("expected a long long type for timestamp");
 		return -1;
 	}
diff --git a/tracecmd/trace-read.c b/tracecmd/trace-read.c
index 03c0978..0d16b15 100644
--- a/tracecmd/trace-read.c
+++ b/tracecmd/trace-read.c
@@ -798,7 +798,7 @@ void trace_show_data(struct tracecmd_input *handle, struct tep_record *record)
 		tep_print_event_time(pevent, &s, event, record,
 					use_trace_clock);
 		buf[0] = 0;
-		if (use_trace_clock && !tep_check_flag(pevent, TEP_NSEC_OUTPUT))
+		if (use_trace_clock && !tep_test_flag(pevent, TEP_NSEC_OUTPUT))
 			rec_ts = (rec_ts + 500) / 1000;
 		if (last_ts) {
 			diff_ts = rec_ts - last_ts;

diff --git a/lib/traceevent/event-parse-api.c b/lib/traceevent/event-parse-api.c
index 2c70375..f2e5d18 100644
--- a/lib/traceevent/event-parse-api.c
+++ b/lib/traceevent/event-parse-api.c
@@ -58,39 +58,38 @@ int tep_get_events_count(struct tep_handle *tep)
  *
  * This sets a flag or combination of flags from enum tep_flag
  */
-void tep_set_flag(struct tep_handle *tep, enum tep_flag flag)
+void tep_set_flag(struct tep_handle *tep, int flag)
 {
 	if (tep)
 		tep->flags |= flag;
 }
 
 /**
  * tep_reset_flag - reset event parser flag
  * @tep: a handle to the tep_handle
- * @flag: flag, or combination of flags to be reseted
- * can be any combination from enum tep_flag
+ * @flag: flag to be cleared
  *
- * This resets a flag or combination of flags from enum tep_flag
+ * This clears a tep flag
  */
-void tep_reset_flag(struct tep_handle *tep, enum tep_flag flag)
+void tep_clear_flag(struct tep_handle *tep, enum tep_flag flag)
 {
 	if (tep)
 		tep->flags &= ~flag;
 }
 
 /**
  * tep_check_flag - check the state of event parser flag
  * @tep: a handle to the tep_handle
- * @flag: flag, or combination of flags to be checked
- * can be any combination from enum tep_flag
+ * @flag: flag to be checked
  *
- * This checks the state of a flag or combination of flags from enum tep_flag
+ * This returns the state of the requested tep flag.
+ * Returns: true if the flag is set, false otherwise.
  */
-int tep_check_flag(struct tep_handle *tep, enum tep_flag flag)
+bool tep_test_flag(struct tep_handle *tep, enum tep_flag flag)
 {
 	if (tep)
 		return (tep->flags & flag);
-	return 0;
+	return false;
 }
 
 unsigned short tep_data2host2(struct tep_handle *pevent, unsigned short data)
@@ -156,13 +155,13 @@ int tep_get_header_page_size(struct tep_handle *pevent)
 }
 
 /**
  * tep_get_header_page_ts_size - get size of the time stamp in the header page
  * @tep: a handle to the tep_handle
  *
  * This returns size of the time stamp in the header page
  * If @tep is NULL, 0 is returned.
  */
-int tep_get_header_page_ts_size(struct tep_handle *tep)
+int tep_get_header_timestamp_size(struct tep_handle *tep)
 {
 	if (tep)
 		return tep->header_page_ts_size;
@@ -361,15 +360,15 @@ int tep_get_parsing_failures(struct tep_handle *tep)
  * tep_is_old_format - get if an old kernel is used
  * @tep: a handle to the tep_handle
  *
- * This returns 1, if an old kernel is used to generate the tracing events or
- * 0 if a new kernel is used. Old kernels did not have header page info.
- * If @pevent is NULL, 0 is returned.
+ * This returns true, if an old kernel is used to generate the tracing events or
+ * false if a new kernel is used. Old kernels did not have header page info.
+ * If @tep is NULL, false is returned.
  */
-int tep_is_old_format(struct tep_handle *tep)
+bool tep_is_old_format(struct tep_handle *tep)
 {
 	if (tep)
-		return tep->old_format;
-	return 0;
+		return !!(tep->old_format);
+	return false;
 }
 
 /**
@@ -386,13 +385,13 @@ void tep_set_print_raw(struct tep_handle *tep, int print_raw)
 }
 
 /**
- * tep_set_print_raw - set a flag to test a filter string
+ * tep_set_test_filters - set a flag to test a filter string
  * @tep: a handle to the tep_handle
  * @test_filters: the new value of the test_filters flag
  *
- * This sets a flag to fjust test a filter string. If this flag is set,
- * when a filter string is added, then it will print the filters strings
- * that were created and exit.
+ * This sets a flag to test a filter string. If this flag is set, when
+ * tep_filter_add_filter_str() API as called,it will print the filter string
+ * instead of adding it.
  */
 void tep_set_test_filters(struct tep_handle *tep, int test_filters)
 {
@@ -58,39 +58,38 @@ int tep_get_events_count(struct tep_handle *tep)
 
 /**
- * tep_reset_flag - reset event parser flag
+ * tep_clear_flag - clear event parser flag
  * @tep: a handle to the tep_handle
@@ -58,39 +58,38 @@ int tep_get_events_count(struct tep_handle *tep)
 
 /**
- * tep_check_flag - check the state of event parser flag
+ * tep_test_flag - check the state of event parser flag
  * @tep: a handle to the tep_handle
@@ -156,13 +155,13 @@ int tep_get_header_page_size(struct tep_handle *pevent)
 
 /**
- * tep_get_header_page_ts_size - get size of the time stamp in the header page
+ * tep_get_header_timestamp_size - get size of the timestamp in the header page
  * @tep: a handle to the tep_handle
  *
@@ -156,13 +155,13 @@ int tep_get_header_page_size(struct tep_handle *pevent)
  * @tep: a handle to the tep_handle
  *
- * This returns size of the time stamp in the header page
+ * This returns size of the timestamp in the header page
  * If @tep is NULL, 0 is returned.
  */